@@ -54,6 +54,8 @@ class Mnemosyne(Component):
         self.components = [
          ("mnemosyne.libmnemosyne.databases.SQLite",
           "SQLite"),
+         ("mnemosyne.libmnemosyne.database",
+          "DatabaseMaintenance"),         
          ("mnemosyne.libmnemosyne.configuration",
           "Configuration"),
          ("mnemosyne.libmnemosyne.loggers.database_logger",
