@@ -63,11 +63,10 @@ class DefaultController(Controller):
             self.config().save()
             self.review_controller().reset()
             self.next_rollover = self.database().start_of_day_n_days_ago(n=-1)
-        #if time.time() > self.config()["last_db_maintenance"] + 90 * DAY:
-        #    print "TMP DEBUG: do db maintenance"
-            #self.component_manager.current("database_maintenance")\
-            #    (self.component_manager).activate()        
-        #    self.config()["last_db_maintenance"] = time.time()
+        if time.time() > self.config()["last_db_maintenance"] + 90 * DAY:
+            self.component_manager.current("database_maintenance").run()        
+            self.config()["last_db_maintenance"] = time.time()
+            self.config().save()
 
     def update_title(self):
         title = _("Mnemosyne")
