@@ -18,6 +18,7 @@ from mnemosyne.libmnemosyne.card import Card
 from mnemosyne.libmnemosyne.translator import _
 from mnemosyne.libmnemosyne.card_type import CardType
 from mnemosyne.libmnemosyne.fact_view import FactView
+from mnemosyne.libmnemosyne.utils import path_exists, path_join
 from mnemosyne.libmnemosyne.utils import expand_path, MnemosyneError
 
 re_src = re.compile(r"""(src|data)=\"(.+?)\"""", re.DOTALL | re.IGNORECASE)
@@ -185,26 +186,27 @@ class SQLiteSync(object):
             """select object_id from log where _id>? and (event_type=? or
             event_type=?)""", (_id, EventTypes.ADDED_MEDIA_FILE,
             EventTypes.EDITED_MEDIA_FILE))]:
-            if os.path.exists(expand_path(filename, self.media_dir())):
-                filenames.add(filename)
+            if path_exists(expand_path(filename, self.media_dir())):
+                filenames.add(filename)                
         return filenames
 
     def all_media_filenames(self):
 
         """Determine all media files, for use in the initial full sync."""
 
+        # We cannot rely on logs in the database here, since part of it
+        # may have been archived, so we simply send across the entire
+        # media directory.
+        
         filenames = set()
-        for filename in [cursor[0] for cursor in self.con.execute(\
-            """select object_id from log where event_type=? or
-            event_type=?""", (EventTypes.ADDED_MEDIA_FILE,
-            EventTypes.EDITED_MEDIA_FILE))]:
-            try:
-                if os.path.exists(expand_path(filename, self.media_dir())):
-                    filenames.add(filename)
-            except UnicodeError:
-                # Workaround Android encoding issue.
-                if os.path.exists(expand_path(filename, self.media_dir()).encode("utf-8")):
-                    filenames.add(filename)                
+        # 'str' needed for Android:
+        for root, dirs, files in os.walk(str(self.media_dir())):
+            subdir = root.replace(self.media_dir(), "")
+            for name in files:
+                filename = path_join(subdir, name)
+                if filename.startswith("\\") or filename.startswith("/"):
+                    filename = filename[1:]
+                filenames.add(filename)
         return filenames
 
     def generate_log_entries_for_settings(self):
@@ -408,22 +410,24 @@ class SQLiteSync(object):
         return log_entry
 
     def add_tag_from_log_entry(self, log_entry):
-        if self.importing:
-            already_imported = self.has_tag_with_id(log_entry["o_id"])
-            same_name_in_database = self.con.execute(\
-                "select count() from tags where name=? and id!=?",
-                (log_entry["name"], log_entry["o_id"])).fetchone()[0] == 1
-            if same_name_in_database:
-                # Merging with the tag which is already in the database is more
-                # difficult, as then the tag links in the cards would need to
-                # be updated.
+        already_imported = self.has_tag_with_id(log_entry["o_id"])
+        if "name" not in log_entry:
+            log_entry["name"] = "dummy"  # Added and immediately deleted.        
+        same_name_in_database = self.con.execute(\
+            "select count() from tags where name=? and id!=?",
+            (log_entry["name"], log_entry["o_id"])).fetchone()[0] == 1
+        if same_name_in_database:
+            # Merging with the tag which is already in the database is more
+            # difficult, as then the tag links in the cards would need to
+            # be updated.
+            if self.importing:  # Don't interrupt sync with dialog.
                 self.main_widget().show_information(\
-            _("Tag '%s' already in database, renaming new tag to '%s (1)'" \
-                % (log_entry["name"], log_entry["name"])))
-                log_entry["name"] += " (1)"
-            if already_imported:
-                log_entry["type"] = EventTypes.EDITED_TAG
-                return self.update_tag(self.tag_from_log_entry(log_entry))
+        _("Tag '%s' already in database, renaming new tag to '%s (1)'" \
+                 % (log_entry["name"], log_entry["name"])))
+            log_entry["name"] += " (1)"
+        if already_imported and self.importing:
+            log_entry["type"] = EventTypes.EDITED_TAG
+            return self.update_tag(self.tag_from_log_entry(log_entry))
         self.add_tag(self.tag_from_log_entry(log_entry))
 
     def tag_from_log_entry(self, log_entry):
@@ -662,7 +666,8 @@ class SQLiteSync(object):
         """
 
         filename = log_entry["fname"]
-        if os.path.exists(expand_path(filename, self.media_dir())):
+        full_path = expand_path(filename, self.media_dir())
+        if path_exists(full_path):
             self.con.execute("""insert or replace into media(filename, _hash)
                 values(?,?)""", (filename, self._media_hash(filename)))
         self.log().added_media_file(filename)
@@ -683,7 +688,7 @@ class SQLiteSync(object):
         #full_path = expand_path(filename, self.media_dir())
         # The file could have been remotely deleted before it got a chance to
         # be synced, so we need to check if the file exists before deleting.
-        #if os.path.exists(full_path):
+        #if path_exists(full_path):
         #    os.remove(full_path)
         #self.log().deleted_media_file(filename)
 
@@ -726,25 +731,27 @@ class SQLiteSync(object):
         return fact_view
 
     def add_card_type_from_log_entry(self, log_entry):
-        if self.importing:
-            already_imported = self.con.execute(\
-                "select count() from card_types where id=?",
-                (log_entry["o_id"], )).fetchone()[0] != 0
-            same_name_in_database = self.con.execute(\
-                "select count() from card_types where name=? and id!=?",
-                (log_entry["name"], log_entry["o_id"] )).fetchone()[0] == 1
-            if same_name_in_database:
-                # Merging with the card type which is already in the database
-                # is more difficult, as then the card type links in the cards
-                # would need to be updated.
+        already_imported = self.con.execute(\
+            "select count() from card_types where id=?",
+            (log_entry["o_id"], )).fetchone()[0] != 0
+        if "name" not in log_entry:
+            log_entry["name"] = "dummy"  # Added and immediately deleted.
+        same_name_in_database = self.con.execute(\
+            "select count() from card_types where name=? and id!=?",
+            (log_entry["name"], log_entry["o_id"] )).fetchone()[0] == 1
+        if same_name_in_database:
+            # Merging with the card type which is already in the database
+            # is more difficult, as then the card type links in the cards
+            # would need to be updated.
+            if self.importing:  # Don't interrupt sync with dialog.
                 self.main_widget().show_information(\
- _("Card type '%s' already in database, renaming new card type to '%s (1)'" \
+    _("Card type '%s' already in database, renaming new card type to '%s (1)'" \
                 % (log_entry["name"], log_entry["name"])))
-                log_entry["name"] += " (1)"
-            if already_imported:
-                log_entry["type"] = EventTypes.EDITED_CARD_TYPE
-                return self.update_card_type(\
-                    self.card_type_from_log_entry(log_entry))
+            log_entry["name"] += " (1)"
+        if already_imported and self.importing:
+            log_entry["type"] = EventTypes.EDITED_CARD_TYPE
+            return self.update_card_type(\
+                self.card_type_from_log_entry(log_entry))
         try:
             card_type = self.card_type_from_log_entry(log_entry)
             self.activate_plugins_for_card_type_with_id(card_type.id)
