@@ -19,8 +19,11 @@ class Upgrade3(Component):
         import cPickle
         old_config_file = \
             file(os.path.join(self.config().config_dir, "config"), "rb")
-        for key, value in cPickle.load(old_config_file).iteritems():
-            if key not in ["import_format", "export_format"]:
-                self.config()[key] = value
+        try:    
+            for key, value in cPickle.load(old_config_file).iteritems():
+                if key not in ["import_format", "export_format"]:
+                    self.config()[key] = value
+        except EOFError:
+            pass
         old_config_file.close() 
             
\ No newline at end of file
