@@ -92,6 +92,7 @@ def copy(src, dst):
 class MnemosyneError(Exception):
     pass
 
+
 def _abs_path(path):
 
     """Our own version of os.path.abspath, which does not check for platform.
@@ -104,6 +105,39 @@ def _abs_path(path):
            or ((len(path) > 2) and path[1] == ":")
 
 
+def path_exists(path):
+    
+    """Our own version of os.path.exists, to deal with unicode issues
+    on Android."""
+    
+    try:
+        return os.path.exists(path)
+    except UnicodeEncodeError:
+        return os.path.exists(path.encode("utf-8"))
+
+    
+def path_getsize(path):
+    
+    """Our own version of os.path.getsize, to deal with unicode issues
+    on Android."""
+    
+    try:
+        return os.path.getsize(path)
+    except UnicodeEncodeError:
+        return os.path.getsize(path.encode("utf-8"))  
+    
+    
+def path_join(path1, path2):
+    
+    """Our own version of os.path.getsize, to deal with unicode issues
+    on Android."""
+    
+    try:
+        return os.path.join(path1, path2)
+    except UnicodeDecodeError:
+        return os.path.join(path1.decode("utf-8"), path2.decode("utf-8"))      
+    
+
 def contract_path(path, start):
 
     """Return relative path to 'path' from the directory 'start'.
