@@ -8,11 +8,19 @@ from mnemosyne.libmnemosyne.translator import _
 from mnemosyne.pyqt_ui.card_set_name_dlg import CardSetNameDlg
 from mnemosyne.pyqt_ui.ui_activate_cards_dlg import Ui_ActivateCardsDlg
 from mnemosyne.libmnemosyne.ui_components.dialogs import ActivateCardsDialog
-
+from mnemosyne.pyqt_ui.tip_after_starting_n_times import \
+     TipAfterStartingNTimes
 
 class ActivateCardsDlg(QtGui.QDialog, Ui_ActivateCardsDlg,
-                       ActivateCardsDialog):
-
+                       ActivateCardsDialog, TipAfterStartingNTimes):
+    
+    started_n_times_counter = "started_activate_cards_n_times"
+    tip_after_n_times = \
+        {3 : _("If you find yourself selecting the same tags and card types many types, you can press the button 'Save this set for later use' to give it a name to select it more quickly later."),
+         6 : _("Double-click on the name of a saved set to quickly activate it and close the dialog."),
+         9 : _("You can right-click on the name of a saved set to rename or delete it."),
+         12 : _("If you single-click the name of a saved set, modifications to the selected tags and card types are not saved to that set unless you press 'Save this set for later use' again. This allows you to make some quick-and-dirty temporary modifications.")}
+    
     def __init__(self, component_manager):
         ActivateCardsDialog.__init__(self, component_manager)
         QtGui.QDialog.__init__(self, self.main_widget())
@@ -22,6 +30,8 @@ class ActivateCardsDlg(QtGui.QDialog, Ui_ActivateCardsDlg,
         self.setWindowFlags(self.windowFlags() \
             & ~ QtCore.Qt.WindowContextHelpButtonHint)
         # Initialise widgets.
+        self.was_showing_a_saved_set = False
+        self.is_shutting_down = False
         criterion = self.database().current_criterion()
         self.criterion_classes = \
             self.component_manager.all("criterion")
@@ -78,10 +88,11 @@ class ActivateCardsDlg(QtGui.QDialog, Ui_ActivateCardsDlg,
         if active_name:
             item = self.saved_sets.findItems(active_name,
                 QtCore.Qt.MatchExactly)[0]
-            self.saved_sets.setCurrentItem(\
-                item, QtGui.QItemSelectionModel.Rows)
+            self.saved_sets.setCurrentItem(item)
+            self.was_showing_a_saved_set = True
         else:
             self.saved_sets.clearSelection()
+            self.was_showing_a_saved_set = False
         splitter_sizes = self.splitter.sizes()
         if self.saved_sets.count() == 0:
             self.splitter.setSizes([0, sum(splitter_sizes)])
@@ -96,7 +107,7 @@ class ActivateCardsDlg(QtGui.QDialog, Ui_ActivateCardsDlg,
         menu.addAction(_("Rename"), self.rename_set)
         menu.exec_(self.saved_sets.mapToGlobal(pos))
 
-    def save_set(self):
+    def save_set(self):        
         criterion = self.tab_widget.currentWidget().criterion()
         if criterion.is_empty():
             self.main_widget().show_error(\
@@ -183,13 +194,18 @@ class ActivateCardsDlg(QtGui.QDialog, Ui_ActivateCardsDlg,
         item = self.saved_sets.findItems(criterion.name,
             QtCore.Qt.MatchExactly)[0]
         self.saved_sets.setCurrentItem(item)
+        self.was_showing_a_saved_set = True
 
     def change_set(self, item, previous_item):
         if previous_item is not None:
             self.load_set(item)
 
-    def select_set_and_close(self, item):
+    def select_set_and_close(self, item): 
         self.load_set(item)
+        # Work around a Qt bug where these calls would still fire when clicking 
+        # in the same area where e.g. the tag browser used to be, even after 
+        # closing the 'Activate cards' window.        
+        self.is_shutting_down = True
         self.accept()
 
     def _store_state(self):
