@@ -12,6 +12,7 @@ from mnemosyne.libmnemosyne.tag import Tag
 from mnemosyne.libmnemosyne.fact import Fact
 from mnemosyne.libmnemosyne.card import Card
 from mnemosyne.libmnemosyne.translator import _
+from mnemosyne.pyqt_ui.qwebview2 import QWebView2
 from mnemosyne.libmnemosyne.component import Component
 from mnemosyne.pyqt_ui.tag_tree_wdgt import TagsTreeWdgt
 from mnemosyne.pyqt_ui.ui_browse_cards_dlg import Ui_BrowseCardsDlg
@@ -118,6 +119,10 @@ class CardModel(QtSql.QSqlTableModel, Component):
             else:
                 return QtCore.QVariant(grade)
         if column == NEXT_REP:
+            grade_index = self.index(index.row(), GRADE)
+            grade = QtSql.QSqlTableModel.data(self, grade_index).toInt()[0]
+            if grade < 2:
+                return QtCore.QVariant("")
             next_rep = QtSql.QSqlTableModel.data(self, index, role).toInt()[0]
             if next_rep <= 0:
                 return QtCore.QVariant("")
@@ -141,15 +146,14 @@ class CardModel(QtSql.QSqlTableModel, Component):
 
 class QA_Delegate(QtGui.QStyledItemDelegate, Component):
 
-    # http://stackoverflow.com/questions/1956542/
-    # how-to-make-item-view-render-rich-html-text-in-qt
+    """Uses webview to render the questions and answers."""
 
     def __init__(self, component_manager, Q_or_A, parent=None):
         Component.__init__(self, component_manager)
         QtGui.QStyledItemDelegate.__init__(self, parent)
-        self.doc = QtGui.QTextDocument(self)
+        self.doc = QWebView2()
         self.Q_or_A = Q_or_A
-
+        
     # We need to reimplement the database access functions here using Qt's
     # database driver. Otherwise, both Qt and libmnemosyne try to claim
     # ownership at the same time. We don't reconstruct everything in order
@@ -222,30 +226,34 @@ class QA_Delegate(QtGui.QStyledItemDelegate, Component):
         # Get the data.
         _id_index = index.model().index(index.row(), _ID)
         _id = index.model().data(_id_index).toInt()[0]
-        ignore_text_colour = bool(optionV4.state & QtGui.QStyle.State_Selected)
+        if optionV4.state & QtGui.QStyle.State_Selected:
+            force_text_colour = optionV4.palette.color(\
+                QtGui.QPalette.Active, QtGui.QPalette.HighlightedText).rgb()
+        else:
+            force_text_colour = None
         search_string = index.model().search_string
         card = self.card(_id)
         if self.Q_or_A == QUESTION:
             self.doc.setHtml(card.question(render_chain="card_browser",
-                ignore_text_colour=ignore_text_colour,
+                force_text_colour=force_text_colour,
                 search_string=search_string))
         else:
             self.doc.setHtml(card.answer(render_chain="card_browser",
-                ignore_text_colour=ignore_text_colour,
+                force_text_colour=force_text_colour,
                 search_string=search_string))
-        # Paint the item without the text.
-        optionV4.text = QtCore.QString()
-        style.drawControl(QtGui.QStyle.CE_ItemViewItem, optionV4, painter)
-        context = QtGui.QAbstractTextDocumentLayout.PaintContext()
-        # Highlight text if item is selected.
-        if optionV4.state & QtGui.QStyle.State_Selected:
-            context.palette.setColor(QtGui.QPalette.Text,
-                optionV4.palette.color(QtGui.QPalette.Active,
-                                       QtGui.QPalette.HighlightedText))
+        # Background colour.
         rect = \
              style.subElementRect(QtGui.QStyle.SE_ItemViewItemText, optionV4)
+        if optionV4.state & QtGui.QStyle.State_Selected:
+            background_colour = optionV4.palette.color(QtGui.QPalette.Active,
+                                       QtGui.QPalette.Highlight)
+        else:
+            background_colour = index.model().background_colour_for_card_type_id.\
+                get(card.card_type.id, None)
+        if background_colour:
+            painter.fillRect(rect, background_colour)
         painter.save()
-
+        
         # No longer used (done in model for all columns),
         # but kept for reference.
         #if not (optionV4.state & QtGui.QStyle.State_Selected) and \
@@ -253,11 +261,12 @@ class QA_Delegate(QtGui.QStyledItemDelegate, Component):
         #     painter.fillRect(rect, QtGui.QColor("red"))
 
         painter.translate(rect.topLeft())
-        painter.translate(0, 3)  # There seems to be a small offset needed...
         painter.setClipRect(rect.translated(-rect.topLeft()))
-        self.doc.documentLayout().draw(painter, context)
-        painter.restore()
-
+        self.doc.setStyleSheet("background:transparent")
+        self.doc.setAttribute(QtCore.Qt.WA_TranslucentBackground)     
+        self.doc.render(painter)
+        painter.restore()            
+        
 
 class BrowseCardsDlg(QtGui.QDialog, Ui_BrowseCardsDlg, BrowseCardsDialog,
                      TipAfterStartingNTimes):
@@ -470,6 +479,7 @@ class BrowseCardsDlg(QtGui.QDialog, Ui_BrowseCardsDlg, BrowseCardsDialog,
             shift = -1
         elif up_down == self.edit_dlg.DOWN:
             shift = 1
+        print shift, current_row + shift
         self.table.selectRow(current_row + shift)
         _card_ids = self._card_ids_from_selection()
         card = self.database().card(_card_ids.pop(), is_id_internal=True)
@@ -698,7 +708,7 @@ class BrowseCardsDlg(QtGui.QDialog, Ui_BrowseCardsDlg, BrowseCardsDialog,
             if len(self.saved_selection) < 10:
                 for index in self.saved_selection:
                     self.table.selectRow(index.row())
-            self.table.setSelectionMode(old_selection_mode)
+            self.table.setSelectionMode(old_selection_mode)   
 
     def reload_database_and_redraw(self):
         self.load_qt_database()
@@ -718,7 +728,7 @@ _("You chose to sort this table. Operations in the card browser could now be slo
         # keypress was 300 ms ago.
         self.timer.start(300)
 
-    def update_filter(self):
+    def update_filter(self):  
         # Card types and fact views.
         criterion = DefaultCriterion(self.component_manager)
         self.card_type_tree_wdgt.checked_to_criterion(criterion)
