@@ -4,6 +4,9 @@
 
 from PyQt4 import QtGui
 
+from matplotlib import use
+use("Qt4Agg")
+
 from matplotlib import rcParams
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
