@@ -12,7 +12,8 @@ import httplib
 
 from partner import Partner
 from text_formats.xml_format import XMLFormat
-from utils import traceback_string, SyncError, SeriousSyncError
+from utils import SyncError, SeriousSyncError
+from utils import path_exists, path_getsize, path_join, traceback_string
 
 # Avoid delays caused by Nagle's algorithm.
 # http://www.cmlenz.net/archives/2008/03/python-httplib-performance-problems
@@ -155,7 +156,8 @@ class Client(Partner):
                 self.resolve_conflicts(restored_from_backup=True)
             # First sync, fetch database from server.
             elif self.database.is_empty():
-                self.get_server_media_files()
+                self.get_server_media_files(redownload_all=True)
+                self.get_server_archive_files()
                 if self.server_info["supports_binary_transfer"]:
                     self.get_server_entire_database_binary()
                 else:
@@ -171,6 +173,7 @@ class Client(Partner):
                     self.server_info["is_database_empty"] and \
                     self.supports_binary_upload():
                 self.put_client_media_files(reupload_all=True)
+                self.put_client_archive_files()
                 self.put_client_entire_database_binary()
                 self.get_sync_finish()
                 # Upload config settings.
@@ -225,7 +228,7 @@ class Client(Partner):
                 self.con.close()
             self.ui.close_progress()
 
-    def supports_binary_upload(self):
+    def supports_binary_upload(self):        
         return self.capabilities == "mnemosyne_dynamic_cards" and \
             self.interested_in_old_reps and self.store_pregenerated_data \
             and self.program_name == self.server_info["program_name"] and \
@@ -239,7 +242,7 @@ class Client(Partner):
                 "you need to choose which copy of the database to keep and " + \
                 "which copy to discard.\n"
         else:
-            message = "Conflicts detected during sync! Choose which version to keep and which version to discard."
+            message = "Conflicts detected during sync! This typically happens if you review the same card on both machines. Choose which version to keep and which version to discard."
         # Ask for conflict resolution direction.
         if self.supports_binary_upload():
             result = self.ui.show_question(message,
@@ -258,6 +261,7 @@ class Client(Partner):
         # with a third party will also trigger a full sync.
         if result == "KEEP_REMOTE":
             self.get_server_media_files(redownload_all=True)
+            self.get_server_archive_files()
             if self.server_info["supports_binary_transfer"]:
                 self.get_server_entire_database_binary()
             else:
@@ -267,6 +271,7 @@ class Client(Partner):
         # Keep local.
         elif result == "KEEP_LOCAL":
             self.put_client_media_files(reupload_all=True)
+            self.put_client_archive_files()
             self.put_client_entire_database_binary()
             self.get_sync_finish()
         # Cancel.
@@ -514,25 +519,54 @@ class Client(Partner):
 
     def put_client_media_files(self, reupload_all=False):
         self.ui.set_progress_text("Sending media files...")
+        # Get list of filenames in the format <mediadir>/<filename>, i.e.
+        # relative to the data_dir. Note we always use / internally. 
+        subdir = os.path.basename(self.database.media_dir())
         if reupload_all:
-            filenames = list(self.database.all_media_filenames())
+            filenames = [subdir + "/" + filename for filename in \
+                         self.database.all_media_filenames()]
         else:
-            filenames = list(self.database.media_filenames_to_sync_for(\
-                self.server_info["machine_id"]))
+            filenames = [subdir + "/" + filename for filename in \
+                         self.database.media_filenames_to_sync_for(\
+                         self.server_info["machine_id"])]
+        # Calculate file size and upload.
+        total_size = 0
+        for filename in filenames:
+            total_size += path_getsize(os.path.join(\
+                self.database.data_dir(), filename))
+        self.put_client_binary_files(filenames, total_size)
+        self.ui.close_progress()
+          
+    def put_client_archive_files(self):  
+        archive_dir = os.path.join(self.database.data_dir(), "archive")
+        if not os.path.exists(archive_dir):
+            return
+        # Get list of filenames in the format "archive"/<filename>, i.e.
+        # relative to the data_dir. Note we always use / internally. 
+        self.ui.set_progress_text("Sending archive files...")       
+        filenames = ["archive/" + filename for filename in \
+                     os.listdir(archive_dir) if os.path.isfile\
+                     (os.path.join(archive_dir, filename))]
+        # Calculate file size and upload.
         total_size = 0
         for filename in filenames:
             total_size += os.path.getsize(os.path.join(\
-                self.database.media_dir(), filename))
+                self.database.data_dir(), filename))
+        self.put_client_binary_files(filenames, total_size)
+        self.ui.close_progress()        
+            
+    def put_client_binary_files(self, filenames, total_size):   
+        # Filenames are relative to the data_dir.
         self.ui.set_progress_range(total_size)
         self.ui.set_progress_update_interval(total_size/50)
         for filename in filenames:
             self.request_connection()
             self.con.putrequest("PUT",
-                self.url("/client_media_file?session_token=%s&filename=%s" \
+                self.url("/client_binary_file?session_token=%s&filename=%s" \
                 % (self.server_info["session_token"],
                 urllib.quote(filename.encode("utf-8"), ""))))
-            full_path = os.path.join(self.database.media_dir(), filename)
-            file_size = os.path.getsize(full_path)
+            full_path = path_join(self.database.data_dir(), filename)
+            file_size = path_getsize(full_path)
             self.con.putheader("content-length", file_size)
             self.con.endheaders()
             for buffer in self.stream_binary_file(full_path, progress_bar=False):
@@ -544,6 +578,7 @@ class Client(Partner):
     def get_server_media_files(self, redownload_all=False):
         self.ui.set_progress_text("Getting list of media files to download...")
         # Get list of names of all media files to download.
+        # Filenames are relative to the data_dir.
         media_url = "/server_media_filenames?session_token=%s" \
             % (self.server_info["session_token"], )
         if redownload_all:
@@ -558,15 +593,43 @@ class Client(Partner):
             # since we reuse our connection.
             response.read()
             return
-        # Download each media file.
-        self.ui.set_progress_text("Getting media files...")
-        self.ui.set_progress_range(total_size)
-        self.ui.set_progress_update_interval(total_size/50)
+        filenames = []
         for filename in response.read().split("\n"):
-            filename = unicode(filename, "utf-8")
+            filenames.append(unicode(filename, "utf-8"))
+        self.ui.set_progress_text("Getting media files...")
+        self.get_server_binary_files(filenames, total_size)    
+        self.ui.close_progress()
+  
+    def get_server_archive_files(self):
+        self.ui.set_progress_text("Getting list of archive files to download...")
+        # Get list of names of all archive files to download.
+        # Filenames are relative to the data_dir.
+        archive_url = "/server_archive_filenames?session_token=%s" \
+            % (self.server_info["session_token"], )
+        self.request_connection()
+        self.con.request("GET", self.url(archive_url))
+        response = self.con.getresponse()
+        self._check_response_for_errors(response, can_consume_response=False)
+        total_size = int(response.getheader("mnemosyne-content-length"))
+        if total_size == 0:
+            # Make sure to read the full message, even if it's empty,
+            # since we reuse our connection.
+            response.read()
+            return
+        filenames = []
+        for filename in response.read().split("\n"):
+            filenames.append(unicode(filename, "utf-8"))
+        self.ui.set_progress_text("Getting archive files...")
+        self.get_server_binary_files(filenames, total_size)    
+        self.ui.close_progress()  
+               
+    def get_server_binary_files(self, filenames, total_size):
+        self.ui.set_progress_range(total_size)
+        self.ui.set_progress_update_interval(total_size/50)  
+        for filename in filenames:
             self.request_connection()
             self.con.request("GET",
-                self.url("/server_media_file?session_token=%s&filename=%s" \
+                self.url("/server_binary_file?session_token=%s&filename=%s" \
                 % (self.server_info["session_token"],
                 urllib.quote(filename.encode("utf-8"), ""))))
             response = self.con.getresponse()
@@ -577,7 +640,7 @@ class Client(Partner):
             # of the media directory.
             filename = filename.replace("../", "").replace("..\\", "")
             filename = filename.replace("/..", "").replace("\\..", "")
-            filename = os.path.join(self.database.media_dir(), filename)
+            filename = os.path.join(self.database.data_dir(), filename)
             self.download_binary_file(response, filename,
                                       file_size, progress_bar=False)
             self.ui.increase_progress(file_size)
