@@ -320,6 +320,7 @@ class Server(Partner):
                 client_info_repr)
             if not self.authorise(client_info["username"],
                 client_info["password"]):
+                self.ui.close_progress()
                 return self.text_format.repr_message("Access denied")
             # Close old session waiting in vain for client input.
             # This will also close any session which timed out while
@@ -348,11 +349,13 @@ class Server(Partner):
                (client_in_server_partners and not server_in_client_partners):
                 if not session.client_info["is_database_empty"]:
                     self.terminate_session_with_token(session.token)
+                    self.ui.close_progress()
                     return self.text_format.repr_message("Sync cycle detected")
             # Detect the case where a user has copied the entire mnemosyne
             # directory before syncing.
             if session.client_info["machine_id"] == self.machine_id:
                 self.terminate_session_with_token(session.token)
+                self.ui.close_progress()
                 return self.text_format.repr_message("same machine ids")
             # Create partnerships.
             session.database.create_if_needed_partnership_with(\
@@ -565,7 +568,7 @@ class Server(Partner):
         except:
             return self.handle_error(session, traceback_string())
 
-    def put_client_media_file(self, environ, session_token, filename):
+    def put_client_binary_file(self, environ, session_token, filename):
         try:
             session = self.sessions[session_token]
             socket = environ["wsgi.input"]
@@ -575,8 +578,8 @@ class Server(Partner):
             # of the media directory.
             filename = filename.replace("../", "").replace("..\\", "")
             filename = filename.replace("/..", "").replace("\\..", "")            
-            filename = os.path.join(session.database.media_dir(), filename)
-            # We don't have progress bars here, as 'put_client_media_file'
+            filename = os.path.join(session.database.data_dir(), filename)
+            # We don't have progress bars here, as 'put_client_binary_file'
             # gets called too frequently, and this would slow down the UI.
             self.download_binary_file(environ["wsgi.input"], filename, size,
                 progress_bar=False)
@@ -591,21 +594,49 @@ class Server(Partner):
             global mnemosyne_content_length
             mnemosyne_content_length = 0
             self.ui.set_progress_text("Sending media files...")
+            # Send list of filenames in the format <mediadir>/<filename>, i.e.
+            # relative to the data_dir. Note we always use / internally.           
+            subdir = os.path.basename(session.database.media_dir())
             if redownload_all in ["1", "True", "true"]:
-                filenames = list(session.database.all_media_filenames())
+                filenames = [subdir + "/" + filename for filename in \
+                             session.database.all_media_filenames()]                
             else:
-                filenames = list(session.database.media_filenames_to_sync_for(\
-                    session.client_info["machine_id"]))
+                filenames = [subdir + "/" + filename  for filename in \
+                             session.database.media_filenames_to_sync_for(\
+                                 session.client_info["machine_id"])]                 
             if len(filenames) == 0:
                 return ""
             for filename in filenames:
-                mnemosyne_content_length += os.path.getsize(\
-                    os.path.join(session.database.media_dir(), filename))
+                mnemosyne_content_length += os.path.getsize((os.path.join(\
+                        session.database.data_dir(), filename)))
             return "\n".join(filenames).encode("utf-8")
         except:
             return self.handle_error(session, traceback_string())
 
-    def get_server_media_file(self, environ, session_token, filename):
+    def get_server_archive_filenames(self, environ, session_token):
+        try:
+            session = self.sessions[session_token]
+            global mnemosyne_content_length
+            mnemosyne_content_length = 0
+            self.ui.set_progress_text("Sending archive files...")
+            # Send list of filenames in the format "archive"/<filename>, i.e.
+            # relative to the data_dir. Note we always use / internally.       
+            archive_dir = os.path.join(session.database.data_dir(), "archive")
+            if not os.path.exists(archive_dir):
+                return ""
+            filenames = ["archive/" + filename for filename in \
+                         os.listdir(archive_dir) if os.path.isfile\
+                         (os.path.join(archive_dir, filename))]            
+            if len(filenames) == 0:
+                return ""
+            for filename in filenames:
+                mnemosyne_content_length += os.path.getsize(os.path.join(\
+                        session.database.data_dir(), filename))
+            return "\n".join(filenames).encode("utf-8")
+        except:
+            return self.handle_error(session, traceback_string())
+
+    def get_server_binary_file(self, environ, session_token, filename):
         try:
             session = self.sessions[session_token]
             global mnemosyne_content_length
@@ -615,7 +646,7 @@ class Server(Partner):
             # of the media directory.
             filename = filename.replace("../", "").replace("..\\", "")
             filename = filename.replace("/..", "").replace("\\..", "")
-            filename = os.path.join(session.database.media_dir(), filename)
+            filename = os.path.join(session.database.data_dir(), filename)
             file_size = os.path.getsize(filename)
             mnemosyne_content_length = file_size
             # Since we want to modify the headers in this function, we cannot
